@@ -6,4 +6,4 @@ from pydantic import BaseModel, Extra
 
 
 class Config(BaseModel, extra=Extra.ignore):
-    update_time: int = 360
\ No newline at end of file
+    update_time: int = 720  # 更新时间间隔 [分钟]
\ No newline at end of file
